"use client";
import { createContext, useContext, useState, useEffect } from "react";
import { useRouter, useSearchParams, usePathname } from "next/navigation";
export const ThemeContext = createContext();

export const useAppContext = () => useContext(ThemeContext);

export const ThemeProvider = ({ children }) => {
  const [theme, setTheme] = useState("light");
  const [text, setText] = useState("");
  const [isDisabled, setIsDisabled] = useState(false);
  const router = useRouter();
  const pathName = usePathname();
  const searchParams = useSearchParams();
  const search = searchParams.get("search");

  useEffect(() => {
    const storedTheme = localStorage.getItem("theme");
    setTheme(storedTheme);
  }, [theme]);
  useEffect(() => {
    if (!search) {
      setText("");
    } else {
      setText(search);
    }
    if (pathName.includes("singleblog")) {
      setIsDisabled(true);
    } else {
      setIsDisabled(false);
    }
  }, [pathName, search]);

  const toggleTheme = () => {
    const newTheme = theme === "light" ? "dark" : "light";
    localStorage.setItem("theme", newTheme);
    setTheme(newTheme);
  };
  const handleSearchInput = (value, currentPage) => {
    setText(value);

    const query = value
      ? `?page=${currentPage}&search=${value}`
      : `?page=${currentPage}`;

    router.push(query, undefined, { shallow: true });
  };
  const contextValue = {
    theme,
    toggleTheme,
    text,
    handleSearchInput,
    isDisabled,
  };

  return (
    <ThemeContext.Provider value={contextValue}>
      <body className={theme}>{children}</body>
    </ThemeContext.Provider>
  );
};
