import PropTypes from "prop-types";
import Image from "next/image";
import Link from "next/link";
import Icons from "@components/base/icons";
import styles from "./styles.module.css";

const Card = ({
  slug,
  title,
  description,
  images,
  publishedDate,
  author,
  readingTime,
}) => {
  return (
    <div className={styles.card}>
      <div className={styles["card-body"]}>
        <Link href={`singleblog/${slug}`}>
          <Image
            className={styles.img}
            src={images.card.url}
            height={images.card.height}
            width={images.card.width}
            loading="eager"
            alt={title}
          />
          <p className={styles.title}>{title}</p>
        </Link>
        <div className={styles["card-content"]}>
          <p className={styles.description}>{description}</p>
          <div className={styles["card-author"]}>
            <Image
              className={styles.img}
              src={author.image.url}
              height={author.image.height}
              width={author.image.width}
              loading="eager"
              alt={author}
            />
            <div className={styles.authordescription}>
              <p className={styles.authorName}>{author.name}</p>
              <div className={styles["author-desc"]}>
                {publishedDate}
                <span className={styles.icon}>
                  <Icons name="clock" size="small" />
                  <span className="readtime">{readingTime}</span>
                </span>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};
Card.propTypes = {
  title: PropTypes.string,
  description: PropTypes.string,
  images: PropTypes.shape({
    card: PropTypes.shape({
      url: PropTypes.string,
      height: PropTypes.number,
      width: PropTypes.number,
    }),
  }),
  publishedDate: PropTypes.string,
  author: PropTypes.shape({
    name: PropTypes.string,
    image: PropTypes.shape({
      url: PropTypes.string,
      height: PropTypes.number,
      width: PropTypes.number, // Use PropTypes.string for images
    }),
  }),

  readingTime: PropTypes.string,
};

export default Card;
