import PropTypes from "prop-types";
import Image from "next/image";
import ReactMarkdown from "react-markdown";
import rehypeRaw from "rehype-raw";
import styles from "./styles.module.css";

function SingleBlog({
  title,
  publishedDate,
  author,
  images,
  category,
  readingTime,
  categories,
  markdown,
}) {
  return (
    <div className={styles.container}>
      <div className={styles.headtitle}>
        <h1 className={styles.title}>{title}</h1>
      </div>
      <div className={styles.blogList}>
        <ul>
          <li>
            Posted on&nbsp;
            <span className={styles.listBold}>{publishedDate}</span>
          </li>
          <li>
            By&nbsp;
            <a href="#" className={styles.listBold}>
              {author.name}
            </a>
          </li>
          <li>
            Published in&nbsp;
            <a href="#" className={styles.listBold}>
              {category}
            </a>
          </li>
          <li>
            <a href="#" className={styles.listBold}>
              {readingTime} read
            </a>
          </li>
        </ul>
      </div>

      <div className={styles.blogContainer}>
        <div className={styles.blogImage}>
          <Image
            className={styles.img}
            src={images.banner.url}
            alt={author.name}
            width={images.banner.width}
            height={images.banner.height}
          />
        </div>
        <div className={styles.blogContent}>
          <ReactMarkdown rehypePlugins={[rehypeRaw]}>{markdown}</ReactMarkdown>
          <div className={styles.tag}>
            <span>Tags:</span>
            {categories.map((category, index) => (
              <p key={index}>{category}</p>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
}

SingleBlog.propTypes = {
  title: PropTypes.string,
  publishedDate: PropTypes.string,
  author: PropTypes.shape({
    name: PropTypes.string,
  }),
  blogImage: PropTypes.shape({
    url: PropTypes.string,
    width: PropTypes.number,
    height: PropTypes.number,
  }),
  category: PropTypes.string,
  readingTime: PropTypes.string,
  categories: PropTypes.array,
  markdown: PropTypes.any,
};

export default SingleBlog;
